The fontFeatures library
========================

.. automodule:: fontFeatures
    :no-members:

.. autoclass:: fontFeatures.FontFeatures
    :members:

Routines: representing collections of layout rules
--------------------------------------------------

.. autoclass:: fontFeatures.Routine
    :members:

.. autoclass:: fontFeatures.RoutineReference
    :members:

.. autoclass:: fontFeatures.ExtensionRoutine
    :members:

Representing individual layout rules
------------------------------------

.. autoclass:: fontFeatures.Rule
    :members:

.. autoclass:: fontFeatures.Substitution
	:members:

.. autoclass:: fontFeatures.Positioning
    :members:

.. autoclass:: fontFeatures.Attachment
    :members:

.. autoclass:: fontFeatures.Chaining
    :members:

Value Records
-------------

.. autoclass:: fontFeatures.ValueRecord
    :members:

